import asyncio
import sys
from mcp import ClientSession, StdioServerParameters
from mcp.client.stdio import stdio_client

async def main():
    server_params = StdioServerParameters(
        command="/app/auto-mcp-upload/.venv/bin/python",
        args=["-c", "import sys; sys.path.insert(0, '/app/auto-mcp-upload/data/3608'); from server import main; main()"],
    )
    
    async with stdio_client(server_params) as (read, write):
        async with ClientSession(read, write) as session:
            await session.initialize()
            
            tools = await session.list_tools()
            print(f"✅ 连接成功！发现 {len(tools.tools)} 个工具:")
            for tool in tools.tools:
                print(f"  - {tool.name}: {tool.description}")
            
            if len(tools.tools) >= 2:
                print(f"\n✅ 本地测试通过！工具数量: {len(tools.tools)}")
                return 0
            else:
                print(f"\n❌ 本地测试失败！工具数量不足: {len(tools.tools)}")
                return 1

if __name__ == "__main__":
    exit_code = asyncio.run(main())
    sys.exit(exit_code)



import asyncio
import logging
import os
from typing import List, Iterator

from fast_diff_mcp import unified_diff
from fastmcp import FastMCP
import difflib

logger: logging.Logger = logging.getLogger(__name__)
mcp: FastMCP = FastMCP("fast-diff-mcp")


@mcp.tool()
def diff_tool_rust_similar(original_text: str, modified_text: str) -> str:
    """
    Compares two multiline strings and returns the difference in the
    standard unified diff format. This is a high-performance implementation
    written in Rust, using the `similar` crate's Myers diff algorithm.
    """
    logger.info(">>> Tool: 'diff_tool_rust_similar' called")
    return unified_diff(original_text, modified_text)


@mcp.tool()
def diff_tool_python_difflib(original_text: str, modified_text: str) -> str:
    """
    Compares two multiline strings using the standard Python `difflib`
    library, which uses the Ratcliff/Obershelp algorithm.
    """
    logger.info(">>> Tool: 'diff_tool_python_difflib' called")
    original_lines: List[str] = original_text.splitlines(keepends=True)
    modified_lines: List[str] = modified_text.splitlines(keepends=True)
    diff: Iterator[str] = difflib.unified_diff(
        original_lines, modified_lines, "original", "modified"
    )
    return "".join(diff)


def main():
    """Main entry point for the MCP server."""
    logging.basicConfig(format="[%(levelname)s]: %(message)s", level=logging.INFO)
    
    # Check if environment variable MCP_TRANSPORT is set, default to stdio
    transport = os.getenv("MCP_TRANSPORT", "stdio")
    
    if transport == "stdio":
        # Run in stdio mode
        logger.info("Starting MCP server in stdio mode")
        asyncio.run(mcp.run(transport="stdio"))
    else:
        # Run in streamable-http mode
        port = int(os.getenv("PORT", 8080))
        logger.info(f"Starting MCP server in streamable-http mode on port {port}")
        asyncio.run(
            mcp.run_async(
                transport="streamable-http",
                host="0.0.0.0",
                port=port,
            )
        )


if __name__ == "__main__":
    main()



import asyncio
from mcp import ClientSession, StdioServerParameters
from mcp.client.stdio import stdio_client

async def main():
    # Use uvx-like approach with python -m
    server_params = StdioServerParameters(
        command="/app/auto-mcp-upload/.venv/bin/python",
        args=["server.py"],
        env={"PYTHONPATH": "/app/auto-mcp-upload/data/3608"}
    )
    
    async with stdio_client(server_params) as (read, write):
        async with ClientSession(read, write) as session:
            await session.initialize()
            
            tools = await session.list_tools()
            print(f"✅ 连接成功！发现 {len(tools.tools)} 个工具:")
            for tool in tools.tools:
                print(f"  - {tool.name}: {tool.description}")
            
            return len(tools.tools)

if __name__ == "__main__":
    count = asyncio.run(main())
    if count and count > 0:
        print(f"\n✅ 测试通过！工具数量: {count}")
    else:
        print("\n❌ 测试失败！")
        sys.exit(1)



import asyncio
import sys
from mcp import ClientSession, StdioServerParameters
from mcp.client.stdio import stdio_client

async def main():
    # Create server parameters for stdio
    server_params = StdioServerParameters(
        command="/app/auto-mcp-upload/.venv/bin/python",
        args=["-c", "import sys; sys.path.insert(0, '/app/auto-mcp-upload/data/3608'); from server import mcp; asyncio.run(mcp.run(transport='stdio'))"],
    )
    
    # Connect to the server
    async with stdio_client(server_params) as (read, write):
        async with ClientSession(read, write) as session:
            # Initialize
            await session.initialize()
            
            # List tools
            tools = await session.list_tools()
            print(f"✅ 连接成功！发现 {len(tools.tools)} 个工具:")
            for tool in tools.tools:
                print(f"  - {tool.name}: {tool.description}")
            
            # Test diff_tool_rust_similar
            if any(t.name == "diff_tool_rust_similar" for t in tools.tools):
                result = await session.call_tool("diff_tool_rust_similar", {
                    "original_text": "Hello World",
                    "modified_text": "Hello Python"
                })
                print(f"\n✅ 测试 diff_tool_rust_similar 成功!")
                print(f"结果: {result.content[0].text[:200]}")

if __name__ == "__main__":
    asyncio.run(main())



import logging
import random
from typing import Tuple

import pyperf
from faker import Faker

from fastmcp import Client
from server import mcp


def generate_test_texts() -> Tuple[str, str]:
    """Generate a pair of texts for benchmarking."""
    fake = Faker()
    text_a = fake.text(max_nb_chars=10000000)
    words = text_a.split()

    if not words:
        return text_a, text_a

    word_to_replace = random.choice(words)
    replacement_word = fake.word()
    while replacement_word == word_to_replace:
        replacement_word = fake.word()

    text_b = text_a.replace(word_to_replace, replacement_word, 1)
    return text_a, text_b


async def run_bench(tool_name: str, text_a: str, text_b: str) -> None:
    """Asynchronous benchmark function."""

    async with Client(mcp) as client:
        await client.call_tool(
            tool_name,
            {"original_text": text_a, "modified_text": text_b},
        )


def main() -> None:
    """Sets up and runs the benchmarks."""
    logging.basicConfig(level=logging.WARNING)

    text_a, text_b = generate_test_texts()

    runner = pyperf.Runner()

    runner.bench_async_func(
        "Rust (`similar` crate)",
        run_bench,
        "diff_tool_rust_similar",
        text_a,
        text_b,
    )
    runner.bench_async_func(
        "Python (`difflib` stdlib)",
        run_bench,
        "diff_tool_python_difflib",
        text_a,
        text_b,
    )


if __name__ == "__main__":
    main()



# flake8: noqa: PYI021
def unified_diff(text1, text2):
    """
    Compares two multiline strings and returns the difference in the
    standard unified diff format. This is a high-performance implementation
    written in Rust.
    """
